Index: apps/app_chanspy.c
===================================================================
--- apps/app_chanspy.c	(revision 75083)
+++ apps/app_chanspy.c	(working copy)
@@ -83,6 +83,9 @@
 "    W             - Enable 'private whisper' mode, so the spying channel can\n"
 "                    talk to the spied-on channel but cannot listen to that\n"
 "                    channel.\n"
+"    e(ext)        - Enable 'enforced' mode, so the spying channel can\n"
+"                    only monitor extensions whose name is in the 'ext' : \n"
+"                    delimited list.\n"
 ;
 
 static const char *app_ext = "ExtenSpy";
@@ -121,12 +124,14 @@
 	OPTION_RECORD    = (1 << 4),
 	OPTION_WHISPER	 = (1 << 5),
 	OPTION_PRIVATE   = (1 << 6),	/* Private Whisper mode */
+	OPTION_ENFORCED  = (1 << 7),    /* Enforced mode */
 } chanspy_opt_flags;
 
 enum {
 	OPT_ARG_VOLUME = 0,
 	OPT_ARG_GROUP,
 	OPT_ARG_RECORD,
+	OPT_ARG_ENFORCED,
 	OPT_ARG_ARRAY_SIZE,
 } chanspy_opt_args;
 
@@ -138,6 +143,7 @@
 	AST_APP_OPTION_ARG('v', OPTION_VOLUME, OPT_ARG_VOLUME),
 	AST_APP_OPTION_ARG('g', OPTION_GROUP, OPT_ARG_GROUP),
 	AST_APP_OPTION_ARG('r', OPTION_RECORD, OPT_ARG_RECORD),
+	AST_APP_OPTION_ARG('e', OPTION_ENFORCED, OPT_ARG_ENFORCED),
 });
 
 
@@ -426,7 +432,7 @@
 }
 
 static int common_exec(struct ast_channel *chan, const struct ast_flags *flags,
-		       int volfactor, const int fd, const char *mygroup, const char *spec,
+		       int volfactor, const int fd, const char *mygroup, const char *myenforced, const char *spec,
 		       const char *exten, const char *context)
 {
 	struct ast_channel *peer, *prev, *next;
@@ -474,6 +480,10 @@
 			char *groups[25];
 			int num_groups = 0;
 			char *dup_group;
+			char *form_enforced;
+			int ienf = !myenforced;
+			char *ext;
+			char *end;
 			int x;
 			char *s;
 				
@@ -507,6 +517,32 @@
 			if (!igrp)
 				continue;
 
+			if (myenforced) {
+
+
+				ext = alloca(strlen(peer->name));
+				form_enforced = alloca(strlen(myenforced) + 3);
+				
+				strcpy(form_enforced, ":");
+				strcat(form_enforced, myenforced);
+				strcat(form_enforced, ":");
+				
+				ext = ast_strdupa(peer->name);
+				ext = strchr(ext, '/');
+				*ext = ':';
+				if ((end = strchr(ext, '-'))) {
+				    *end++ = ':';
+				    *end = '\0';
+				}
+
+				if (strstr(form_enforced, ext))
+					ienf = 1;
+
+			}
+			
+			if (!ienf)
+				continue;
+
 			strcpy(peer_name, "spy-");
 			strncat(peer_name, peer->name, AST_NAME_STRLEN);
 			ptr = strchr(peer_name, '/');
@@ -562,6 +598,7 @@
 	char *spec = NULL;
 	char *argv[2];
 	char *mygroup = NULL;
+	char *myenforced = NULL;
 	char *recbase = NULL;
 	int fd = 0;
 	struct ast_flags flags;
@@ -605,6 +642,10 @@
 
 		if (ast_test_flag(&flags, OPTION_PRIVATE))
 			ast_set_flag(&flags, OPTION_WHISPER);
+		
+		if (ast_test_flag(&flags, OPTION_ENFORCED))
+			myenforced = opts[OPT_ARG_ENFORCED];
+		
 	} else
 		ast_clear_flag(&flags, AST_FLAGS_ALL);
 
@@ -625,7 +666,7 @@
 		}
 	}
 
-	res = common_exec(chan, &flags, volfactor, fd, mygroup, spec, NULL, NULL);
+	res = common_exec(chan, &flags, volfactor, fd, mygroup, myenforced, spec, NULL, NULL);
 
 	if (fd)
 		close(fd);
@@ -710,7 +751,7 @@
 		}
 	}
 
-	res = common_exec(chan, &flags, volfactor, fd, mygroup, NULL, exten, context);
+	res = common_exec(chan, &flags, volfactor, fd, mygroup, NULL, NULL, exten, context);
 
 	if (fd)
 		close(fd);
